#
# spec file for package distrobuilder
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           distrobuilder
Version:        3.1
Release:        1.2
Summary:        System container image builder for LXC and LXD/Incus
License:        Apache-2.0
URL:            https://github.com/lxc/distrobuilder
Source0:        %{url}/archive/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
Patch0:         pie.patch
BuildRequires:  debootstrap
BuildRequires:  git-core
BuildRequires:  gpg2
BuildRequires:  make
BuildRequires:  rsync
BuildRequires:  squashfs
BuildRequires:  zstd
BuildRequires:  golang(API) >= 1.21
Requires:       btrfsprogs
Requires:       bzip2
Requires:       debootstrap
Requires:       dirmngr
Requires:       dosfstools
Requires:       e2fsprogs
Requires:       git
Requires:       gpg2
Requires:       gptfdisk
Requires:       gzip
Requires:       hivex
Requires:       lzip
Requires:       lzop
Requires:       mkisofs
Requires:       python3-xattr
Requires:       qemu-img
Requires:       rsync
Requires:       squashfs
Requires:       wimtools
Requires:       xz
Requires:       zstd

%description
%{summary}.

%prep
%autosetup -a1 -p1 -n %{name}-%{name}-%{version}

%build
%make_build

%install
install -D -m 755 $HOME/go/bin/%{name} %{buildroot}%{_bindir}/%{name}

%files
%license COPYING
%doc README.md CONTRIBUTING.md CODE_OF_CONDUCT.md
%{_bindir}/%{name}

%changelog
* Wed Oct 23 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 3.1:
  * gomod: Bump to Go 1.20 minimum
  * Fix small logging issues
  * README: Add note about minimum Go version
  * main: Fix VM builds when using build-lxd command
  * sources: Fix openeuler tests
  * nixos-http: support versioned releases
  * managers: Rebranding Macaroni OS Package Manager
  * Bump golang.org/x/crypto and github.com/containerd/containerd
  * main: Add missing --sources-dir to build-incus command
  * Update README.md Install Instructions
  * Update README.md
  * incus-agent: Refresh files
  * build(deps): bump github.com/opencontainers/runc from 1.1.10 to 1.1.12
  * incus-agent: Fix systemd unit name under LXD
  * Bump to Go 1.21
  * Tidy up lxc.generator a bit
  * incus-agent: Fix SELinux
  * Bump pongo2 to v4
  * Remove race in tests
  * debootstrap: Pass --no-merged-usr on noble
  * Debian sid use --no-merged-usr
  * Replace util.ValueInSlice with slices.Contains
  * Fixed hardcoded root partition device name sda2
  * Updated ubuntu example to use ROOTFS_DEVICE_UUID
  * Switch to Incus 6.0
  * Make run-parts running compatible with different versions
  * Set repack-windows drivers default value
  * Clean up iso mount gen warnings
  * Refactor find boot.wim and install.wim logic
  * Refactor WIM info parsing
  * Support x86 architecture and refactor the detecting logic
  * gomod: Update dependencies by
  * sources/funtoo: Use symlinks
  * archlinux: Move to zst
  * Repack windows bios boot support
  * Refactor copy driver files
  * Refactor parse inf driver class guid
  * Update actions.md by
  * lxc.generator: Handle pre-release systemd
  * systemd v256 seems to require overriding ImportCredential= for all containers
  * Fixed duplicated umount action
  * Support http-proxy keyserver options for gpg recv-keys
  * Refactor import gpg public keys
  * distrobuilder: Remove LXD support
  * Gomod update/cleanup
  * Fixed multiple sys files not copied issue
  * Update README.md
  * Fixed device major minor parse failure
  * Run unit tests via sudo
  * debootstrap: Remove no-merged-usr/merged-usr logic
  * debootstrap: Add workaround for devuan
  * sources: Fix openEuler version in tests
  * workflows/tests: drop 1.21, add 1.23
  * nixos-http: use incus-specific image for unstable
  * Add handling of ESD files for Windows repacking
  * Update gomod
  * Add mkisofs support
- remove mkisofs.patch as upstream added support
- add pie.patch to enable PIE
* Wed Jul 26 2023 Richard Rahl <rrahl0@proton.me>
- Initial packaging of upstream for openSUSE Tumbleweed.
